Encoder<T> typedef
Encoder<T> =
RawSettingValue Function(T)
A function that converts a value of type T to a value of type R.
Implementation
typedef Encoder<T> = RawSettingValue Function(T);
A function that converts a value of type T to a value of type R.
typedef Encoder<T> = RawSettingValue Function(T);