value property

WritableBeacon<T> value
latefinal

The value of the setting. Changing the setting can be done by assigning a new value to this property. The new value will be persisted to the underlying storage.

Implementation

late final WritableBeacon<T> value;