SettingsX extension
Extension methods for Settings.
- on
Methods
-
boolSetting(
{required String key, bool defaultValue = false}) → Setting< bool> -
Available on Settings, provided by the SettingsX extension
Creates a new Setting that manages a bool. -
derivedSetting<
T, I> ({required String key, required ReadableBeacon< I> input, required T decode(RawSettingValue, I), required RawSettingValue encode(T)}) → Setting<T> -
Available on Settings, provided by the SettingsX extension
A Setting that is derived frominput. Any time theinputchanges, thedecodefunction will be invoked with the current value of the returned Setting as well as the new value ofinput. Similarly, any time the returned Setting changes, thedecodefunction will be invoked with the new value of the returned Setting as well as the current value ofinput. -
doubleSetting(
{required String key, double defaultValue = 0.0}) → Setting< double> -
Available on Settings, provided by the SettingsX extension
Creates a new Setting that manages a double. -
intSetting(
{required String key, int defaultValue = 0}) → Setting< int> -
Available on Settings, provided by the SettingsX extension
Creates a new Setting that manages an int. -
stringListSetting(
{required String key}) → Setting< List< String> > -
Available on Settings, provided by the SettingsX extension
Creates a new Setting that manages a List<String>. -
stringSetting(
{required String key}) → Setting< String?> -
Available on Settings, provided by the SettingsX extension
Creates a new Setting that manages a String.