boolSetting method

Setting<bool> boolSetting({
  1. required String key,
  2. bool defaultValue = false,
})

Creates a new Setting that manages a bool.

A single setting that exposes a type T to the consuming application.

The _key is a function that returns the key for the setting. The _decode function is used to convert the raw value from the underlying storage to the type T. The _encode function is used to convert the value of type T to a raw value that can be stored in the underlying storage.

Implementation

Setting<bool> boolSetting({
  required String key,
  bool defaultValue = false,
}) {
  return setting<bool>(
    key: key,
    decode: boolDecoder(defaultValue: defaultValue),
    encode: boolEncoder(),
  );
}