stringListSetting method

Setting<List<String>> stringListSetting({
  1. required String key,
})

Creates a new Setting that manages a List<String>.

A single setting that exposes a type T to the consuming application.

The _key is a function that returns the key for the setting. The _decode function is used to convert the raw value from the underlying storage to the type T. The _encode function is used to convert the value of type T to a raw value that can be stored in the underlying storage.

Implementation

Setting<List<String>> stringListSetting({
  required String key,
}) {
  return setting<List<String>>(
    key: key,
    decode: stringListDecoder(),
    encode: stringListEncoder(),
  );
}